@@ -7,8 +7,8 @@
 #' @examples
 #' \donttest{
 #' try({ # try only shown here because sometimes CRAN checks are weird
-#' jml_conn <- ff_connect(platform = "sleeper", league_id = "522458773317046272", season = 2020)
-#' ff_league(jml_conn)
+#'   jml_conn <- ff_connect(platform = "sleeper", league_id = "522458773317046272", season = 2020)
+#'   ff_league(jml_conn)
 #' }) # end try
 #' }
 #' @describeIn ff_league Sleeper: returns a summary of league features.
@@ -50,11 +50,12 @@ ff_league.sleeper_conn <- function(conn) {
   )
 }
 
-.sleeper_isbestball <- function(league_endpoint){
-
+.sleeper_isbestball <- function(league_endpoint) {
   x <- league_endpoint$settings[["best_ball"]]
 
-  if(!is.null(x) && as.logical(x)) return(TRUE)
+  if (!is.null(x) && as.logical(x)) {
+    return(TRUE)
+  }
 
   return(FALSE)
 }
