@@ -1,5 +1,7 @@
 with_mock_api({
   test_that("ff_draftpicks returns a tibble of draft picks", {
+    skippy()
+
     ssb <- mfl_connect(2020, 54040)
     ssb_picks <- ff_draftpicks(ssb)
 
@@ -21,6 +23,10 @@ with_mock_api({
     joe_conn <- fleaflicker_connect(2020, 206154)
     joe_picks <- ff_draftpicks(joe_conn, franchise_id = 1373475)
 
-    expect_tibble(joe_picks, min.rows = 15)
+    expect_tibble(joe_picks, min.rows = 1)
+
+    dlp <- ff_connect("espn", 1178049)
+
+    expect_warning(ff_draftpicks(dlp), regexp = "ESPN does not support draft pick trades")
   })
 })
